@@ -144,25 +144,9 @@ CREATE TABLE events (
 ;
 
 -- ## BEGIN 5.5
--- MySQL does not support checks, so we kind of create our own. The checkit()
--- function works sort of like a CHECK: if the first argument is 0 or NULL, it
--- throws the second argument as an exception. Conveniently, verify scripts
--- can also use it to ensure an error is thrown when a change cannot be
--- verified. Requires MySQL 5.5.0.
+-- MySQL does not support checks, so we kind of create our own.
 
 DELIMITER |
-
--- ## BEGIN checkit
-CREATE FUNCTION checkit(doit INTEGER, message VARCHAR(256)) RETURNS INTEGER DETERMINISTIC
-BEGIN
-    IF doit IS NULL OR doit = 0 THEN
-        SIGNAL SQLSTATE 'ERR0R' SET MESSAGE_TEXT = message;
-    END IF;
-    RETURN doit;
-END;
-|
--- ## END checkit
-
 CREATE TRIGGER ck_insert_dependency BEFORE INSERT ON dependencies
 FOR EACH ROW BEGIN
     IF (NEW.type = 'require' AND NEW.dependency_id IS NULL)
